==> fred_inquisitor-1.0.0rc4-py3-none-any.whl: inquisitor/tests/test_session.py <==
from contextlib import asynccontextmanager
from datetime import timedelta
from unittest import IsolatedAsyncioTestCase, TestCase
from unittest.mock import ANY, Mock, call

from fakeredis.aioredis import FakeRedis
from fred_types import ContactId
from verifier import ContactData, VerificationId

from inquisitor.auth import TokenData
from inquisitor.session import OIDCSession, get_session
from inquisitor.settings import Settings


class GetSessionTest(IsolatedAsyncioTestCase):
    async def test_get_session(self):
        # This test contains coverage ignores because of Python 3.11 coverage bug.
        # See https://github.com/nedbat/coveragepy/issues/1595
        cache = Mock(wraps=FakeRedis())
        settings = Settings(redis_cache_key_prefix="TEST:", access_token_expires=4242)
        token = TokenData(
            verification_id=VerificationId("v:1"),
            contact_id=ContactId("c:1"),
        )

        # Test that session data is created when not found in cache
        async with asynccontextmanager(get_session)(
            cache=cache, settings=settings, token=token
        ) as session:  # pragma: no cover
            self.assertEqual(session.verification_id, VerificationId("v:1"))
            session.oidc.state = "smeghead"

        # Test that session data has been saved
        async with asynccontextmanager(get_session)(
            cache=cache, settings=settings, token=token
        ) as session:  # pragma: no cover
            self.assertEqual(session.oidc.state, "smeghead")

        # Test that expected cache key is used
        self.assertEqual(  # pragma: no cover
            cache.mock_calls,
            [
                call.get("TEST:session:v:1"),
                call.set("TEST:session:v:1", ANY, ex=timedelta(seconds=4242)),
                call.get("TEST:session:v:1"),
                call.set("TEST:session:v:1", ANY, ex=timedelta(seconds=4242)),
            ],
        )


class OIDCSessionTest(TestCase):
    def test_is_legal_person_no_contact_data(self):
        with self.assertRaises(AssertionError):
            OIDCSession().is_legal_person

    def test_is_legal_person_organization(self):
        data = ContactData(organization="Jupiter Mining Corporation")
        self.assertTrue(OIDCSession(contact_data=data).is_legal_person)

    def test_is_legal_person_no_organization(self):
        data = ContactData(name="Arnold Rimmer")
        self.assertFalse(OIDCSession(contact_data=data).is_legal_person)

    def test_is_trustworthy_legal_person(self):
        data = ContactData(organization="Jupiter Mining Corporation")
        self.assertTrue(OIDCSession(contact_data=data, mojeid_validation=True).is_trustworthy)
        self.assertFalse(OIDCSession(contact_data=data, mojeid_validation=False).is_trustworthy)

    def test_is_trustworthy_physical_person(self):
        data = ContactData(name="Arnold Rimmer")
        self.assertTrue(OIDCSession(contact_data=data, mojeid_nia=True).is_trustworthy)
        self.assertFalse(OIDCSession(contact_data=data, mojeid_nia=False).is_trustworthy)

==> fred_inquisitor-1.3.0-py3-none-any.whl: inquisitor/tests/test_session.py <==
import json
from contextlib import asynccontextmanager
from datetime import timedelta
from unittest import IsolatedAsyncioTestCase, TestCase
from unittest.mock import ANY, Mock, call

from fakeredis.aioredis import FakeRedis
from fred_types import ContactId
from verifier import ContactData, VerificationId

from inquisitor.session import OIDCSession, Session, create_session, get_session
from inquisitor.settings import Settings
from inquisitor.token import TokenData


class CreateSessionTest(IsolatedAsyncioTestCase):
    async def test_create_session(self):  # pragma: no cover
        # This test contains coverage ignores because of Python 3.11 coverage bug.
        # See https://github.com/nedbat/coveragepy/issues/1595
        cache = Mock(wraps=FakeRedis())
        settings = Settings(redis_cache_key_prefix="TEST:", access_token_expires=4242)
        session = Session(verification_id=VerificationId("v:1"), representative_token="Gazpacho!")
        await create_session(session=session, cache=cache, settings=settings)
        session_data = await cache.get("TEST:session:v:1")
        self.assertEqual(Session(**json.loads(session_data)), session)
        self.assertEqual(
            cache.mock_calls,
            [
                call.set("TEST:session:v:1", ANY, ex=timedelta(seconds=4242)),
                call.get("TEST:session:v:1"),
            ],
        )


class GetSessionTest(IsolatedAsyncioTestCase):
    async def test_get_session(self):
        # This test contains coverage ignores because of Python 3.11 coverage bug.
        # See https://github.com/nedbat/coveragepy/issues/1595
        cache = Mock(wraps=FakeRedis())
        settings = Settings(redis_cache_key_prefix="TEST:", access_token_expires=4242)
        token = TokenData(
            verification_id=VerificationId("v:1"),
            contact_id=ContactId("c:1"),
        )

        # Test that session data is created when not found in cache
        async with asynccontextmanager(get_session)(
            cache=cache, settings=settings, token=token
        ) as session:  # pragma: no cover
            self.assertEqual(session.verification_id, VerificationId("v:1"))
            session.oidc.state = "smeghead"

        # Test that session data has been saved
        async with asynccontextmanager(get_session)(
            cache=cache, settings=settings, token=token
        ) as session:  # pragma: no cover
            self.assertEqual(session.oidc.state, "smeghead")

        # Test that expected cache key is used
        self.assertEqual(  # pragma: no cover
            cache.mock_calls,
            [
                call.get("TEST:session:v:1"),
                call.set("TEST:session:v:1", ANY, ex=timedelta(seconds=4242)),
                call.get("TEST:session:v:1"),
                call.set("TEST:session:v:1", ANY, ex=timedelta(seconds=4242)),
            ],
        )


class OIDCSessionTest(TestCase):
    def test_is_legal_person_no_contact_data(self):
        with self.assertRaises(AssertionError):
            OIDCSession().is_legal_person  # noqa: B018

    def test_is_legal_person_organization(self):
        data = ContactData(organization="Jupiter Mining Corporation")
        self.assertTrue(OIDCSession(contact_data=data).is_legal_person)

    def test_is_legal_person_no_organization(self):
        data = ContactData(name="Arnold Rimmer")
        self.assertFalse(OIDCSession(contact_data=data).is_legal_person)

    def test_is_trustworthy_legal_person(self):
        data = ContactData(organization="Jupiter Mining Corporation")
        self.assertTrue(OIDCSession(contact_data=data, mojeid_validation=True).is_trustworthy)
        self.assertFalse(OIDCSession(contact_data=data, mojeid_validation=False).is_trustworthy)

    def test_is_trustworthy_physical_person(self):
        data = ContactData(name="Arnold Rimmer")
        self.assertTrue(OIDCSession(contact_data=data, mojeid_nia=True).is_trustworthy)
        self.assertFalse(OIDCSession(contact_data=data, mojeid_nia=False).is_trustworthy)
